@@ -798,7 +798,7 @@ class CAT(object):
                     try:
                         if max_chars_in_memory > 0:
                             cnt = 0
-                            while (out_dict['current_size_in_chars'] + len(text))) > max_chars_in_memory:
+                            while (out_dict['current_size_in_chars'] + len(text)) > max_chars_in_memory:
                                 cnt += 1
                                 self.log.debug("Process: {}, waiting because current chars in memory: {}".format(pid, out_dict['current_size_in_chars']))
                                 # Wait until size in memory is low
